@@ -26,7 +26,7 @@
 #endif
 
 #define EXEC_ON_CLICK 1
-#define ASMON_VERSION "0.70rc2"
+#define ASMON_VERSION "0.71"
 #define CHAR_WIDTH 5
 #define CHAR_HEIGHT 7
 
@@ -819,6 +819,7 @@ void DrawUptime(void)
 	    old_mins=mins;
 	    if ( days > 9 ) 
 	    	{
+		copyXPMArea(20,105,36,9,18,48);
 	    	tempy=hours%10;
 	    	copyXPMArea(3+(tempy*6),66,6,9,50,48);
 	    	tempy=hours/10;
